@@ -8,14 +8,16 @@ ResamplingSameOtherSizesCV = R6::R6Class(
         seeds = paradox::p_int(1L, tags = "required"),
         ratio = paradox::p_dbl(0,1, tags = "required"),
         sizes = paradox::p_int(-1, tags = "required"),
-        ignore_subset = paradox::p_lgl(tags="required")
+        ignore_subset = paradox::p_lgl(tags="required"),
+        subsets = paradox::p_fct(c("S","O","A","SO","SA","SOA"),tags="required")
       )
       ps$values = list(
         folds=3L,
         seeds=1L,
         ratio=0.5,
         sizes=-1L,
-        ignore_subset=FALSE
+        ignore_subset=FALSE,
+        subsets="SOA"
       )
       super$initialize(
         id = "same_other_sizes_cv",
@@ -49,9 +51,14 @@ ResamplingSameOtherSizesCV = R6::R6Class(
         }
       )
       n.subsets <- length(unique(subset.dt[["test.subset"]]))
-      train.subsets <- c(
-        if(n.subsets>1)c("all","other"),
-        "same")
+      train.subsets <- if(n.subsets==1)"same" else switch(
+        self$param_set$values$subsets,
+        S="same",
+        O="other",
+        A="all",
+        SO=c("same","other"),
+        SA=c("same","all"),
+        SOA=c("same","other","all"))
       n.folds <- self$param_set$values$folds
       acol <- task$col_roles$group
       avec <- if(length(acol)==1){
